==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/content/messages/th/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(ผู้ที่ไม่ใช่สมาชิกของ Space นี้สามารถมองเห็นได้)',
  '<strong>Confirm</strong> post deletion' => '<strong>ยืนยัน</strong> ลบโพสต์',
  '<strong>Delete</strong> content?' => '',
  '<strong>Move</strong> content' => '<strong>ย้าย</strong> เนื้อหา',
  '<strong>Permalink</strong> to this post' => '<strong>ลิงก์ถาวร</strong> ไปยังโพสต์นี้',
  'Add a member to notify' => 'เพิ่มสมาชิกเพื่อแจ้งเตือน',
  'Add tag...' => 'เพิ่มแท็ก...',
  'Archived' => 'ที่เก็บถาวร',
  'Attach Files' => 'แนบไฟล์',
  'Back to stream' => 'กลับไปสตรีม',
  'Cancel' => 'ยกเลิก',
  'Cancel Edit' => 'ยกเลิกการแก้ไข',
  'Change to "Private"' => 'เปลี่ยนเป็น "ส่วนตัว"',
  'Change to "Public"' => 'เปลี่ยนเป็น "สาธารณะ"',
  'Comments are locked' => '',
  'Comments are unlocked' => '',
  'Confirm' => 'ยืนยัน',
  'Content' => 'เนื้อหา',
  'Content Tag with invalid contentcontainer_id assigned.' => 'แท็กเนื้อหาที่มีการกำหนด contentcontainer_id ที่ไม่ถูกต้อง',
  'Content has been moved to {spacename}' => 'ย้ายเนื้อหาไปที่ {spacename} แล้ว',
  'Content visibility' => 'การมองเห็นเนื้อหา',
  'Could not delete content!' => 'ไม่สามารถลบเนื้อหาได้!',
  'Could not find requested content!' => 'ไม่พบเนื้อหาที่ร้องขอ!',
  'Created at:' => 'สร้างเมื่อ:',
  'Created by me' => 'สร้างโดย me',
  'Creation time' => 'เวลาสร้าง',
  'Delete' => 'ลบ',
  'Do you really want to delete this post? All likes and comments will be lost!' => 'คุณต้องการลบโพสต์นี้จริงหรือ ไลค์และคอมเมนต์ทั้งหมดจะหายไป!',
  'Edit' => 'แก้ไข',
  'Filter' => 'กรอง',
  'I\'m involved' => 'ที่ฉันมีส่วนร่วม',
  'Invalid content id given!' => 'ระบุ ID เนื้อหาไม่ถูกต้อง!',
  'Invalid request method!' => 'วิธีการขอไม่ถูกต้อง!',
  'Invalid space selection.' => 'การเลือกพื้นที่ไม่ถูกต้อง',
  'Last update' => 'การปรับปรุงครั้งล่าสุด',
  'Last updated {time}' => 'อัปเดตล่าสุด {time}',
  'Load more' => 'โหลดเพิ่ม',
  'Lock comments' => '',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'ถึงจำนวนสูงสุดของรายการที่ตรึงแล้ว!<br>คุณสามารถตรึงรายการได้สูงสุด {count} รายการในครั้งเดียวเท่านั้น',
  'Move content' => 'ย้ายเนื้อหา',
  'Move to archive' => 'ย้ายไปเก็บถาวร',
  'New Updates Available!' => '',
  'No matches with your selected filters!' => 'ไม่ตรงกับตัวกรองที่คุณเลือก!',
  'No tags found for the given query' => 'ไม่พบแท็กสำหรับข้อความค้นหาที่ระบุ',
  'None' => 'ไม่มี',
  'Nothing here yet!' => 'ยังไม่มีอะไรที่นี่!',
  'Notify members' => 'แจ้งสมาชิก',
  'Permalink' => 'ลิงก์ถาวร',
  'Pin to top' => 'ปักหมุดด้านบน',
  'Pinned' => 'ปักหมุด',
  'Private' => 'เอกชน',
  'Public' => 'สาธารณะ',
  'Select type...' => 'เลือกประเภท...',
  'Specify who can see this content.' => 'ระบุว่าใครสามารถดูเนื้อหานี้ได้',
  'Submit' => 'ส่ง',
  'Tag' => 'แท็ก',
  'Target Space' => 'พื้นที่เป้าหมาย',
  'The author of this content is not allowed to create private content within the selected space.' => 'ผู้เขียนเนื้อหานี้ไม่ได้รับอนุญาตให้สร้างเนื้อหาส่วนตัวภายในพื้นที่ที่เลือก',
  'The author of this content is not allowed to create public content within the selected space.' => 'ผู้เขียนเนื้อหานี้ไม่ได้รับอนุญาตให้สร้างเนื้อหาสาธารณะภายในพื้นที่ที่เลือก',
  'The author of this content is not allowed to create this type of content within this space.' => 'ผู้เขียนเนื้อหานี้ไม่ได้รับอนุญาตให้สร้างเนื้อหาประเภทนี้ภายในพื้นที่นี้',
  'The content can\'t be moved to its current space.' => 'ไม่สามารถย้ายเนื้อหาไปยังพื้นที่ปัจจุบันได้',
  'The content has been archived.' => 'เนื้อหาถูกเก็บถาวรแล้ว',
  'The content has been deleted.' => 'เนื้อหาถูกลบไปแล้ว',
  'The content has been unarchived.' => 'เนื้อหาได้รับการยกเลิกการเก็บถาวร',
  'The given name is already in use.' => 'มีการใช้ชื่อที่ระบุนี้แล้ว',
  'The module {moduleName} is not enabled on the selected target space.' => 'โมดูล {moduleName} ไม่ได้เปิดใช้งานในพื้นที่เป้าหมายที่เลือก',
  'This action is disabled!' => 'การดำเนินการนี้ถูกปิดใช้งาน!',
  'This content type can\'t be moved due to a missing module-id setting.' => 'ไม่สามารถย้ายเนื้อหาประเภทนี้ได้เนื่องจากไม่มีการตั้งค่ารหัสโมดูล',
  'This content type can\'t be moved.' => 'ไม่สามารถย้ายเนื้อหาประเภทนี้ได้',
  'This space is archived.' => 'พื้นที่นี้ถูกเก็บถาวร',
  'This space is not visible!' => 'พื้นที่นี้ไม่สามารถมองเห็นได้!',
  'Topics' => 'หัวข้อ',
  'Turn off notifications' => 'ปิดการแจ้งเตือน',
  'Turn on notifications' => 'เปิดการแจ้งเตือน',
  'Unarchive' => 'ยกเลิกการเก็บถาวร',
  'Unlock comments' => '',
  'Unpin' => 'เลิกตรึง',
  'Updated' => 'อัปเดต',
  'Visible also to unregistered users' => 'ปรากฏแก่ผู้ใช้ที่ไม่ได้ลงทะเบียนด้วย',
  'Visible only to you' => 'มองเห็นได้เฉพาะคุณเท่านั้น',
  'Visible to all Space members' => 'ปรากฏแก่สมาชิก Space ทุกคน',
  'Visible to all signed in users' => 'ปรากฏแก่ผู้ใช้ที่ลงชื่อเข้าใช้ทั้งหมด',
  'Visible to friends of {displayName}' => 'ปรากฏแก่เพื่อนของ {displayName}',
  'Visible to you and {displayName}' => 'ปรากฏแก่คุณและ {displayName}',
  'Visible to your friends' => 'ปรากฏให้เพื่อนของคุณเห็น',
  'With attachments' => 'พร้อมไฟล์แนบ',
  'You cannot block the space owner!' => '',
  'You cannot block the user of the same container!' => '',
  'You cannot block yourself!' => '',
  'You do not have the permission to move this content to the given space.' => 'คุณไม่ได้รับอนุญาตให้ย้ายเนื้อหานี้ไปยังพื้นที่ที่กำหนด',
  'You do not have the permission to move this content.' => 'คุณไม่ได้รับอนุญาตให้ย้ายเนื้อหานี้',
  'Your last edit state has been saved!' => 'บันทึกสถานะการแก้ไขล่าสุดของคุณแล้ว',
  'in' => 'ใน',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/content/messages/th/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(ผู้ที่ไม่ใช่สมาชิกของ Space นี้สามารถมองเห็นได้)',
  '<strong>Confirm</strong> post deletion' => '<strong>ยืนยัน</strong> ลบโพสต์',
  '<strong>Delete</strong> content?' => '<strong>ลบ</strong> เนื้อหา?',
  '<strong>Move</strong> content' => '<strong>ย้าย</strong> เนื้อหา',
  '<strong>Permalink</strong> to this post' => '<strong>ลิงก์ถาวร</strong> ไปยังโพสต์นี้',
  'Add a member to notify' => 'เพิ่มสมาชิกเพื่อแจ้งเตือน',
  'Add tag...' => 'เพิ่มแท็ก...',
  'Archived' => 'ที่เก็บถาวร',
  'Attach Files' => 'แนบไฟล์',
  'Back to stream' => 'กลับไปสตรีม',
  'Cancel' => 'ยกเลิก',
  'Cancel Edit' => 'ยกเลิกการแก้ไข',
  'Change to "Private"' => 'เปลี่ยนเป็น "ส่วนตัว"',
  'Change to "Public"' => 'เปลี่ยนเป็น "สาธารณะ"',
  'Comments are locked' => '',
  'Comments are unlocked' => '',
  'Confirm' => 'ยืนยัน',
  'Content' => 'เนื้อหา',
  'Content Tag with invalid contentcontainer_id assigned.' => 'แท็กเนื้อหาที่มีการกำหนด contentcontainer_id ที่ไม่ถูกต้อง',
  'Content has been moved to {spacename}' => 'ย้ายเนื้อหาไปที่ {spacename} แล้ว',
  'Content visibility' => 'การมองเห็นเนื้อหา',
  'Could not delete content!' => 'ไม่สามารถลบเนื้อหาได้!',
  'Could not find requested content!' => 'ไม่พบเนื้อหาที่ร้องขอ!',
  'Created at:' => 'สร้างเมื่อ:',
  'Created by me' => 'สร้างโดยฉัน',
  'Creation time' => 'เวลาสร้าง',
  'Delete' => 'ลบ',
  'Do you really want to delete this post? All likes and comments will be lost!' => 'คุณต้องการลบโพสต์นี้จริงหรือ ไลค์และคอมเมนต์ทั้งหมดจะหายไป!',
  'Edit' => 'แก้ไข',
  'Filter' => 'กรอง',
  'I\'m involved' => 'ที่ฉันมีส่วนร่วม',
  'Invalid content id given!' => 'ระบุ ID เนื้อหาไม่ถูกต้อง!',
  'Invalid request method!' => 'วิธีการขอไม่ถูกต้อง!',
  'Invalid space selection.' => 'การเลือกพื้นที่ไม่ถูกต้อง',
  'Last update' => 'การปรับปรุงครั้งล่าสุด',
  'Last updated {time}' => 'อัปเดตล่าสุด {time}',
  'Load more' => 'โหลดเพิ่ม',
  'Lock comments' => 'Lock ความคิดเห็น',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'ถึงจำนวนสูงสุดของรายการที่ตรึงแล้ว!<br>คุณสามารถตรึงรายการได้สูงสุด {count} รายการในครั้งเดียวเท่านั้น',
  'Move content' => 'ย้ายเนื้อหา',
  'Move to archive' => 'ย้ายไปเก็บถาวร',
  'New Updates Available!' => '',
  'No matches with your selected filters!' => 'ไม่ตรงกับตัวกรองที่คุณเลือก!',
  'No tags found for the given query' => 'ไม่พบแท็กสำหรับข้อความค้นหาที่ระบุ',
  'None' => 'ไม่มี',
  'Nothing here yet!' => 'ยังไม่มีอะไรที่นี่!',
  'Notify members' => 'แจ้งสมาชิก',
  'Permalink' => 'ลิงก์ถาวร',
  'Pin to top' => 'ปักหมุดด้านบน',
  'Pinned' => 'ปักหมุด',
  'Private' => 'เอกชน',
  'Public' => 'สาธารณะ',
  'Select type...' => 'เลือกประเภท...',
  'Specify who can see this content.' => 'ระบุว่าใครสามารถดูเนื้อหานี้ได้',
  'Submit' => 'ส่ง',
  'Tag' => 'แท็ก',
  'Target Space' => 'พื้นที่เป้าหมาย',
  'The author of this content is not allowed to create private content within the selected space.' => 'ผู้เขียนเนื้อหานี้ไม่ได้รับอนุญาตให้สร้างเนื้อหาส่วนตัวภายในพื้นที่ที่เลือก',
  'The author of this content is not allowed to create public content within the selected space.' => 'ผู้เขียนเนื้อหานี้ไม่ได้รับอนุญาตให้สร้างเนื้อหาสาธารณะภายในพื้นที่ที่เลือก',
  'The author of this content is not allowed to create this type of content within this space.' => 'ผู้เขียนเนื้อหานี้ไม่ได้รับอนุญาตให้สร้างเนื้อหาประเภทนี้ภายในพื้นที่นี้',
  'The content can\'t be moved to its current space.' => 'ไม่สามารถย้ายเนื้อหาไปยังพื้นที่ปัจจุบันได้',
  'The content has been archived.' => 'เนื้อหาถูกเก็บถาวรแล้ว',
  'The content has been deleted.' => 'เนื้อหาถูกลบไปแล้ว',
  'The content has been unarchived.' => 'เนื้อหาได้รับการยกเลิกการเก็บถาวร',
  'The given name is already in use.' => 'มีการใช้ชื่อที่ระบุนี้แล้ว',
  'The module {moduleName} is not enabled on the selected target space.' => 'โมดูล {moduleName} ไม่ได้เปิดใช้งานในพื้นที่เป้าหมายที่เลือก',
  'This action is disabled!' => 'การดำเนินการนี้ถูกปิดใช้งาน!',
  'This content type can\'t be moved due to a missing module-id setting.' => 'ไม่สามารถย้ายเนื้อหาประเภทนี้ได้เนื่องจากไม่มีการตั้งค่ารหัสโมดูล',
  'This content type can\'t be moved.' => 'ไม่สามารถย้ายเนื้อหาประเภทนี้ได้',
  'This space is archived.' => 'พื้นที่นี้ถูกเก็บถาวร',
  'This space is not visible!' => 'พื้นที่นี้ไม่สามารถมองเห็นได้!',
  'Topics' => 'หัวข้อ',
  'Turn off notifications' => 'ปิดการแจ้งเตือน',
  'Turn on notifications' => 'เปิดการแจ้งเตือน',
  'Unarchive' => 'ยกเลิกการเก็บถาวร',
  'Unlock comments' => '',
  'Unpin' => 'เลิกตรึง',
  'Updated' => 'อัปเดต',
  'Visible also to unregistered users' => 'ปรากฏแก่ผู้ใช้ที่ไม่ได้ลงทะเบียนด้วย',
  'Visible only to you' => 'มองเห็นได้เฉพาะคุณเท่านั้น',
  'Visible to all Space members' => 'ปรากฏแก่สมาชิก Space ทุกคน',
  'Visible to all signed in users' => 'ปรากฏแก่ผู้ใช้ที่ลงชื่อเข้าใช้ทั้งหมด',
  'Visible to friends of {displayName}' => 'ปรากฏแก่เพื่อนของ {displayName}',
  'Visible to you and {displayName}' => 'ปรากฏแก่คุณและ {displayName}',
  'Visible to your friends' => 'ปรากฏให้เพื่อนของคุณเห็น',
  'With attachments' => 'พร้อมไฟล์แนบ',
  'You cannot block the space owner!' => '',
  'You cannot block the user of the same container!' => '',
  'You cannot block yourself!' => '',
  'You do not have the permission to move this content to the given space.' => 'คุณไม่ได้รับอนุญาตให้ย้ายเนื้อหานี้ไปยังพื้นที่ที่กำหนด',
  'You do not have the permission to move this content.' => 'คุณไม่ได้รับอนุญาตให้ย้ายเนื้อหานี้',
  'Your last edit state has been saved!' => 'บันทึกสถานะการแก้ไขล่าสุดของคุณแล้ว',
  'in' => 'ใน',
);
